@@ -35,7 +35,6 @@ import supybot.conf as conf
 import supybot.httpserver as httpserver
 import supybot.plugin as plugin
 import supybot.registry as registry
-from supybot.utils.minisix import u
 
 from . import plugin as Aka
 
@@ -180,8 +179,8 @@ class AkaChannelTestCase(ChannelPluginTestCase):
         self.assertResponse('egg', 'baz')
 
     def testComplicatedNames(self):
-        self.assertNotError(u('aka add café "echo coffee"'))
-        self.assertResponse(u('café'), 'coffee')
+        self.assertNotError('aka add café "echo coffee"')
+        self.assertResponse('café', 'coffee')
 
         self.assertNotError('aka add "foo bar" "echo spam"')
         self.assertResponse('foo bar', 'spam')
@@ -241,7 +240,7 @@ class AkaTestCase(PluginTestCase):
 
     def testAliasImport(self):
         self.assertNotError('alias add foo "echo bar"')
-        self.assertNotError(u('alias add baz "echo café"'))
+        self.assertNotError('alias add baz "echo café"')
         self.assertNotError('aka add qux "echo quux"')
         self.assertResponse('alias foo', 'bar')
         self.assertResponse('alias baz', 'café')
