@@ -86,17 +86,16 @@ def sandbox(f):
             return commands.process(
                 f,
                 *args,
-                timeout=10,
+                timeout=20,
                 heap_size=300 * 1024 * 1024,
                 pn="Fediverse",
                 cn=f.__name__,
                 **kwargs
             )
-        except (commands.ProcessTimeoutError, MemoryError):
-            raise web.Error(
-                "Page is too big or the server took "
-                "too much time to answer the request."
-            )
+        except commands.ProcessTimeoutError:
+            raise web.Error("The server took too much time to answer the request.")
+        except MemoryError:
+            raise web.Error("Page is too big to be processed")
 
     return newf
 
