@@ -40,7 +40,6 @@ import supybot.ircdb as ircdb
 import supybot.utils as utils
 
 import re
-import sys
 
 try:
     from supybot.i18n import PluginInternationalization
@@ -48,7 +47,10 @@ try:
 except ImportError:
     _ = lambda x: x
 
-from .constants import SED_REGEX, TAG_SEEN, TAG_IS_REGEX
+from .sedregex import makeSedRegex
+
+TAG_SEEN = 'SedRegex.seen'
+TAG_IS_REGEX = 'SedRegex.isRegex'
 
 # Replace newlines and friends with things like literal "\n" (backslash and "n")
 axe_spaces = utils.str.MultipleReplacer({'\n': '\\n', '\t': '\\t', '\r': '\\r'})
@@ -56,7 +58,7 @@ axe_spaces = utils.str.MultipleReplacer({'\n': '\\n', '\t': '\\t', '\r': '\\r'})
 class SearchNotFoundError(Exception):
     pass
 
-class SedRegex(callbacks.PluginRegexp):
+class SedRegex(callbacks.Plugin):
     """
     Enable SedRegex on the desired channels:
     ``config channel #yourchannel plugins.sedregex.enable True``
@@ -88,11 +90,9 @@ class SedRegex(callbacks.PluginRegexp):
 
     threaded = True
     public = True
-    unaddressedRegexps = ['replacer']
-    flags = 0  # Make callback matching case sensitive
 
     @staticmethod
-    def _unpack_sed(expr):
+    def _unpack_sed(sedRegex, expr):
         if '\0' in expr:
             raise ValueError('Expression can\'t contain NUL')
 
@@ -107,7 +107,7 @@ class SedRegex(callbacks.PluginRegexp):
 
             escaped_expr += c
 
-        match = SED_REGEX.search(escaped_expr)
+        match = sedRegex.search(escaped_expr)
 
         if not match:
             return
@@ -134,33 +134,32 @@ class SedRegex(callbacks.PluginRegexp):
 
         return (pattern, replacement, count, raw_flags)
 
-    # Tag all messages that SedRegex has seen before. This slightly optimizes the ignoreRegex
-    # feature as all messages tagged with SedRegex.seen but not SedRegex.isRegex is NOT a regexp.
-    # If we didn't have this tag, we'd have to run a regexp match on each message in the history
-    # to check if it's a regexp, as there could've been regexp-like messages sent before
-    # SedRegex was enabled.
-    def doNotice(self, irc, msg):
-        if self.registryValue('enable', msg.channel, irc.network):
-            msg.tag(TAG_SEEN)
-
     def doPrivmsg(self, irc, msg):
-       # callbacks.PluginRegexp works by defining doPrivmsg(), we don't want to overwrite
-       # its behaviour
-       super().doPrivmsg(irc, msg)
-       self.doNotice(irc, msg)
-
-    # SedRegex main routine. This is called automatically by callbacks.PluginRegexp on every
-    # message that matches the SED_REGEX expression defined in constants.py
-    # The actual regexp is passed into PluginRegexp by setting __doc__ equal to the regexp.
-    def replacer(self, irc, msg, regex):
         if not self.registryValue('enable', msg.channel, irc.network):
             return
-        self.log.debug("SedRegex: running on %s/%s for %s", irc.network, msg.channel, regex)
+
+        # Tag all messages that SedRegex has seen before. This slightly optimizes the ignoreRegex
+        # feature as all messages tagged with SedRegex.seen but not SedRegex.isRegex is NOT a regexp.
+        # If we didn't have this tag, we'd have to run a regexp match on each message in the history
+        # to check if it's a regexp, as there could've been regexp-like messages sent before
+        # SedRegex was enabled.
+        msg.tag(TAG_SEEN)
+
+        delimiters = self.registryValue('delimiters', msg.channel, irc.network)
+        if delimiters:
+            delimiters = re.escape(delimiters)
+        sedRegex = makeSedRegex(delimiters)
+        text = msg.args[1]
+        regexMatch = sedRegex.match(text)
+        if not regexMatch:
+            return
+
+        self.log.debug("SedRegex: running on %s/%s for %s", irc.network, msg.channel, regexMatch)
         iterable = reversed(irc.state.history)
         msg.tag(TAG_IS_REGEX)
 
         try:
-            (pattern, replacement, count, flags) = self._unpack_sed(msg.args[1])
+            (pattern, replacement, count, flags) = self._unpack_sed(sedRegex, text)
         except Exception as e:
             self.log.warning(_("SedRegex parser error: %s"), e, exc_info=True)
             if self.registryValue('displayErrors', msg.channel, irc.network):
@@ -171,14 +170,14 @@ class SedRegex(callbacks.PluginRegexp):
         if 's' in flags:  # Special 's' flag lets the bot only look at self messages
             target = msg.nick
         else:
-            target = regex.group('nick')
+            target = regexMatch.group('nick')
         if not ircutils.isNick(str(target)):
             return
 
         regex_timeout = self.registryValue('processTimeout')
         try:
             message = process(self._replacer_process, irc, msg,
-                    target, pattern, replacement, count, iterable,
+                    target, pattern, replacement, count, iterable, sedRegex,
                     timeout=regex_timeout, pn=self.name(), cn='replacer')
         except ProcessTimeoutError:
             irc.error(_("Search timed out."))
@@ -192,9 +191,8 @@ class SedRegex(callbacks.PluginRegexp):
                     e.__class__.__name__, e))
         else:
             irc.reply(message, prefixNick=False)
-    replacer.__doc__ = SED_REGEX.pattern
 
-    def _replacer_process(self, irc, msg, target, pattern, replacement, count, messages):
+    def _replacer_process(self, irc, msg, target, pattern, replacement, count, messages, sedRegex):
         for m in messages:
             if m.command in ('PRIVMSG', 'NOTICE') and \
                     ircutils.strEqual(m.args[0], msg.args[0]) and m.tagged('receivedBy') == irc:
@@ -216,7 +214,7 @@ class SedRegex(callbacks.PluginRegexp):
                 # so we only need to do this check once per message.
                 if not m.tagged(TAG_SEEN):
                     m.tag(TAG_SEEN)
-                    if SED_REGEX.match(m.args[1]):
+                    if sedRegex.match(m.args[1]):
                         m.tag(TAG_IS_REGEX)
                 # Ignore messages containing a regexp if ignoreRegex is on.
                 if self.registryValue('ignoreRegex', msg.channel, irc.network) and m.tagged(TAG_IS_REGEX):
@@ -251,6 +249,7 @@ class SedRegex(callbacks.PluginRegexp):
         self.log.debug(_("SedRegex: Search %r not found in the last %i messages of %s."),
                          msg.args[1], len(irc.state.history), msg.args[0])
         raise SearchNotFoundError()
+    doNotice = doPrivmsg
 
 Class = SedRegex
 
