@@ -68,7 +68,7 @@ class ValidNickSet(conf.ValidNicks):
 
 Services = conf.registerPlugin('Services')
 conf.registerNetworkValue(Services, 'nicks',
-    ValidNickSet([], _("""Determines what nicks the bot will use with
+    ValidNickSet([], _("""Space-separated list of nicks the bot will use with
     services.""")))
 
 class Networks(registry.SpaceSeparatedSetOfStrings):
@@ -86,6 +86,10 @@ conf.registerNetworkValue(Services, 'noJoinsUntilIdentified',
 conf.registerNetworkValue(Services, 'ghostDelay',
     registry.NonNegativeInteger(60, _("""Determines how many seconds the bot will
     wait between successive GHOST attempts. Set this to 0 to disable GHOST.""")))
+conf.registerNetworkValue(Services, 'ghostCommand',
+    registry.String("GHOST", _("""Determines the NickServ command to use for GHOST. If the network
+    you're using runs Anope, set this to "RECOVER". If the network you're using runs Atheme,
+    set this to "GHOST" or "REGAIN".""")))
 conf.registerNetworkValue(Services, 'NickServ',
     ValidNickOrEmptyString('NickServ', _("""Determines what nick the 'NickServ' service
     has.""")))
