@@ -74,9 +74,9 @@ class FunctionsTestCase(SupyTestCase):
         self.assertNotEqual(f(irc, msg, '$today'), '$today')
         self.assertNotEqual(f(irc, msg, '$now'), '$now')
         n = f(irc, msg, '$randnick')
-        self.assertTrue(n in irc.state.channels['#foo'].users)
+        self.assertIn(n, irc.state.channels['#foo'].users)
         n = f(irc, msg, '$randomnick')
-        self.assertTrue(n in irc.state.channels['#foo'].users)
+        self.assertIn(n, irc.state.channels['#foo'].users)
         n = f(irc, msg, '$randomnick '*100)
         L = n.split()
         self.assertFalse(all(L[0].__eq__, L), 'all $randomnicks were the same')
